import { useCallback, useEffect } from "react";
import config from "./config.json"

export default function App() {
  const loadScript = useCallback(() => {
    return new Promise((resolve, reject) => {
      if (!document.querySelector("#payrixScript")) {
        const script = document.createElement("script");
        script.src = "https://test-api.payrix.com/payFieldsScript?spa=1";
        script.id = "payrixScript";
        script.async = true;
        script.onload = () => resolve(script);
        script.onerror = () => reject(new Error("Failure attaching script"));
        document.body.appendChild(script);
        console.log("loaded script");
      }
    });
  });

  async function handleClick(e) {
    if (window.PayFields) {
      if (window.PayFields.isValid()) {
        await window.PayFields.submit();
      }
    }
  }

  function GIACT(txnId) {
    return new Promise((resolve, reject) => {
      try {
        fetch(`http://localhost:5000/giact-data/${txnId}`)
          .then((response) => response.json())
          .then((data) => {
            resolve(data.action);
          });
      } catch (error) {
        console.log("Failed to call GIACT verification service");
        reject(error);
      }
    });
  }

  useEffect(() => {
    const initScript = async () => {
      await loadScript().then((_) => {
        window.PayFields.config.merchant = config.merchant
        window.PayFields.config.apiKey = config.public_api_key
        window.PayFields.config.googlePay.environment = "TEST";
        window.PayFields.config.mode = "txn";
        window.PayFields.config.amount = "1";
        window.PayFields.config.txnType = "ecsale";

        window.PayFields.config.billingAddress = {
          address: "123 Madison Street",
          city: "New York",
          state: "NY",
          zip: "12345",
          email: "test@test.com",
          phone: "2223456789",
        };

        window.PayFields.fields = [
          { type: "name", element: "#nameACH" },
          { type: "routing", element: "#routing" },
          { type: "account_type", element: "#account_type", value: "Dinosaur" },
          { type: "account_number", element: "#account_number" },
        ];

        window.PayFields.customizations = {
          style: {
            ".form-error": {
              display: "none",
            },
            ".name": {
              maxWidth: "94%",
            },
            ".number": {
              maxWidth: "97%",
            },
            ".cvv": {
              maxWidth: "20%",
            },
            ".expiration": {
              width: "85%",
              borderRadius: "6px",
            },
            ".card-icon": {
              display: "none",
            },
          },
        };

        window.PayFields.onSuccess = (response) => {
          console.log(response);
        };

        window.PayFields.onFailure = (response) => {
          let transactionId = response.data[0] 
          ? response.data[0].id 
          : console.log("no transaction Id found") 

          if ((window.PayFields.config.txnType = "ecsale")) {
            GIACT(transactionId)
            .then(res =>
              res == "BLOCK"
                ? alert("**ADVERSE ACTION NOTICE** \n\n 1) Check if you have entered correct bank account and routing details.\n\n 2) Check if your bank account is in good standing. \n\n 3) If the details are correct and is in good standing, This notice is intended to comply with the requirements of the federal Fair Credit Reporting (FCRA). We are unable to process your request because we were unable to verify or authenticate your account information. Our decision was based in whole, or in part, on information obtained from a consumer reporting agency, Giact Systems, LLC. However, Giact Systems, LLC played no part in the decision process and is unable to supply specific reasons for the denial of services. Under the FCRA, you have a right to know the information contained within your report. You also have a right to make a written request, no later than 60-days after you receive this notice, for disclosure of this information. You may request a free consumer report from Giact Systems, LLC no later than 60-days following the receipt of this notice. You may also dispute information contained in the report if you believe that it is inaccurate or incomplete. Giact Systems, LLC’s contact information is provided below: GIACT Systems, LLC 700 Central Expy S. Suite 300 Allen, TX 75013 1 (833) 802-8092.")
                : alert("giact error response")
            );
          }
          //Non GIACT error
          console.log(response);
        };

        console.log(window.PayFields);

        window?.PayFields.ready();
      });
    };
    initScript();
    return () => {
      window.PayFields.unmountAll();
    };
  }, []);
  return (
    <>
      <h1>Client Side</h1>
      <div>
        <label htmlFor="customer_id"> name: </label>
        <div id="nameACH" className="form-row"></div>
      </div>
      <div>
        <label htmlFor="customer_id">routing: </label>
        <div id="routing" className="form-row"></div>
      </div>
      <div>
        <label htmlFor="customer_id"> account_type: </label>
        <div id="account_type" className="form-row"></div>
      </div>
      <div>
        <label htmlFor="customer_id"> account_number: </label>
        <div id="account_number" className="form-row"></div>
      </div>
      <div className="button-container">
        <button type="button" id="button" name="Submit" onClick={handleClick}>
          Submit
        </button>
        <button id="swipe" type="button" name="button">
          Swipe
        </button>
      </div>
    </>
  );
}
